django-permissions-auditor
==========================

Automatically parse Django views in your project and pull out the permissions required to view them. Easily extensible to work with custom permission schemes.
